@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "elfeed-curate" "0.3.0"
+(define-package "elfeed-curate" "20251026.311"
   "Elfeed entry curation."
   '((emacs  "27.1")
     (elfeed "3.4.1"))
